import pytest
from selenium.webdriver.common.by import By

from Pages.businessKnowledge_page import BusinessKnowledgePage
from Pages.login_page import LoginPage
from Util.Util import DriverUtils
import time
from loguru import  logger
from Util.handle_path import yaml_path



class TestBusinessKnowledge:
    test_data = DriverUtils.read_yaml(str(yaml_path)+"/test_data.yml")
    urls = test_data["urls"]
    folder_names = test_data["folder_names"]
    documents = test_data['documents']


    def setup_class(self):
        # 在所有的测试用例脚本之前执行一次
        # 完成公共部分初始化
        self.driver = DriverUtils.get_web_driver()
        self.login_page = LoginPage()
        self.business_page = BusinessKnowledgePage()
        self.driver.get('https://rays7.raysgo.com/login')
        self.login_page.login_username("17373027967", "3149390154Li")
        self.business_page.entranceAi()  # 进入AI编辑室
        self.business_page.entranceBusinessKnowledge()  # 进入企业知识库
        time.sleep(3)


    def teardown_class(self):
        # 在所有的测试用例脚本之后执行一次
        self.driver.quit()
        pass

    def setup_method(self):
        # 在每个测试用例脚本之前执行一次
       pass

    def teardown_method(self):
        # 在每个测试用例脚本之后执行一次
        pass

    # 新建文件夹 0-20 重复文件名
    @pytest.mark.run(order=1)
    @pytest.mark.displayName("新建文件夹")
    @pytest.mark.parametrize("folder_name", folder_names)
    def test_newFolder_case001(self,folder_name):
        """
        测试用例1：新建文件夹
        """
        # 需要判断此文件名存不存在
        self.business_page.newFolderControl(folder_name)
        time.sleep(3)
        # 断言
        folders = self.business_page.find_el(self.business_page.folders).find_elements(By.XPATH,".//span")
        assert folder_name == self.business_page.get_text_ele(folders[(len(folders)-1)])
        logger.info(f"新建文件成功，文件名为：{folder_name}")

    # 更新文件夹名字 0-20 重复文件名
    # def test_updateFolder_case001(self):
    #     expect_folder_name = "xxxx322x"
    #     actual_folder_name = self.business_page.updateFolderControl(expect_folder_name)
    #     time.sleep(2)
    #     # 断言
    #     assert actual_folder_name == expect_folder_name
    #     logger.info("更新文件名字成功")


    # 删除文件夹
    @pytest.mark.run(order=2)
    @pytest.mark.displayName("删除文件夹")
    @pytest.mark.parametrize("execution_count", [3])
    def test_deleteFolder_case001(self,execution_count):
        """
        测试用例2：删除文件夹
        """
        for _ in range(execution_count):
            self.business_page.deleteFolderControl()



    # 切换文件夹
    @pytest.mark.run(order=3)
    def test_traverse_folder(self):
        try:
            self.business_page.traverseFolder()
            assert 1 == 1
        except Exception as e:
            logger.info("错误类型：{e}")
    # 搜索
    @pytest.mark.run(order=4)
    def test_search_document(self, key_name = "世界"):
        logger.info("----------------------文档搜索用例开始执行----------------------")
        try:
            documents = self.business_page.searchDocument(key_name)
            flag = self.business_page.isExistKeyInDocument(key_name,documents)
            assert flag == True
            logger.info(f"搜索文件关键字为:{key_name}-成功")
        except Exception as e:
            logger.error(f"发生报错：报错信息为{e}")
            assert 0 == 1
        logger.info("----------------------文档搜索用例执行结束----------------------")


    # 文档上传
    @pytest.mark.run(order=5)
    def test_upload_document_case001(self):
        try:
            logger.info("----------------------文档上传用例开始执行----------------------")
            stry_paths = []
            stry_paths.append("t"+str(0+1)+".txt")
            self.business_page.upload_document_helper.uploadDocumentControl(stry_paths)
            time.sleep(1)
            # 断言  实际 == 预期
            assert self.business_page.document_list_helper.get_all_documents_by_index_type(0,2) == "学习完成"
        except Exception as e:
            logger.error(f"发生报错：报错信息为{e}")
            assert 0 == 1
        logger.info("----------------------文档上传用例执行介绍----------------------")

        # 导入网站 此处的url可以做成数据驱动
        # 使用 @pytest.mark.parametrize 装饰器
    @pytest.mark.run(order=6)
    @pytest.mark.parametrize("document", documents)
    def test_upload_website_case003(self, document):
        logger.info("----------------------文档上传用例开始执行----------------------")
        self.business_page.upload_document_helper.pasteTextControl(document['title'],document['content'])
        time.sleep(30)
        # 断言

        assert self.business_page.document_list_helper.get_all_documents_by_index_type(0, 2) == "学习完成"
        logger.info("----------------------文档上传用例执行介绍----------------------")

    # 导入网站 此处的url可以做成数据驱动
    # 使用 @pytest.mark.parametrize 装饰器
    @pytest.mark.run(order=6)
    @pytest.mark.parametrize("url", urls)
    def test_upload_website_case001(self,url):
        logger.info("----------------------文档上传用例开始执行----------------------")
        self.business_page.upload_document_helper.uploadUrlControl(url)
        time.sleep(30)
        # 断言
        assert self.business_page.document_list_helper.get_all_documents_by_index_type(0,2) == "学习完成"
        logger.info("----------------------文档上传用例执行介绍----------------------")



